@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.17";
+our $VERSION = "2.18";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -379,23 +379,25 @@ sub fold {
     ## --boundary=word
     ##
     if ($word_char_re
-	and my($tail) = /\A(${word_char_re}+)/
+	and my($tail) = /\A( (?: ${word_char_re} \cH ? ) + )/x
 	and $folded =~ m{
 		^
 		( (?: [^\e]* ${csi_re}++ ) *+ )
 		( .*? )
-		( ${word_char_re}+ )
+		( (?: ${word_char_re} \cH ? ) + )
 		\z
 	}x
 	) {
 	## Break line before word only when enough space will be
 	## provided for the word in the next turn.
 	my($s, $e) = ($-[3], $+[3]);
-	my $l = $e - $s;
+	my $head = $3;
+	s/.\cH//g for $head, $tail;
+	my $l = length $head;
 	## prefix length
 	my $p = $opt->{prefix} eq '' ? 0 : vwidth $opt->{prefix};
 	if ($room + $l < $width - $p and $l + length($tail) <= $width - $p) {
-	    $_ = substr($folded, $s, $l, '') . pop_reset() . $_;
+	    $_ = substr($folded, $s, $e - $s, '') . pop_reset() . $_;
 	    $room += $l;
 	}
     }
@@ -552,7 +554,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.17
+Version 2.18
 
 =head1 SYNOPSIS
 
@@ -891,6 +893,10 @@ text with Japanese prohibited character handling.
 
 =over 7
 
+=item L<https://github.com/tecolicom/ANSI-Tools>
+
+Collection of ANSI related tools.
+
 =item L<Text::ANSI::Fold>
 
 =item L<https://github.com/kaz-utashiro/Text-ANSI-Fold>
@@ -947,7 +953,7 @@ Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright 2018-2022 Kazumasa Utashiro.
+Copyright 2018-2023 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
